@@ -15,4 +15,15 @@ result = predictor.predict(
     main_coverage=0.4
 )
 
-print("Predicted probabilities:", result)
\ No newline at end of file
+print("Predicted probabilities:", result)
+
+# Run prediction for 2NN with example values
+result_2nn = predictor.predict_2nn(
+    facet=111,
+    interaction_energy_1nn=0.16,
+    interaction_energy_2nn=0.04,
+    temperature=525,
+    main_coverage=0.7
+)
+
+print("Predicted 2NN probabilities:", result_2nn)
\ No newline at end of file
